@@ -24,7 +24,7 @@
 #include <libgnome/gnome-i18n.h>
 #include <string.h>
 #include <glade/glade.h>
-#include <gal/widgets/widget-color-combo.h>
+#include "gi-color-combo.h"
 
 #include "htmlclue.h"
 #include "htmlcolor.h"
@@ -414,7 +414,7 @@ cell_widget (GtkHTMLEditCellProperties *d)
 	GtkWidget *cell_page;
 	GladeXML *xml;
 
-	xml = glade_xml_new (GLADE_DATADIR "/gtkhtml-editor-properties.glade", "cell_page", NULL);
+	xml = glade_xml_new (GLADE_DATADIR "/gtkhtml-editor-properties.glade", "cell_page", GETTEXT_PACKAGE);
 	if (!xml)
 		g_error (_("Could not load glade file."));
 
