@@ -23,6 +23,7 @@
 
 #include <config.h>
 #include "htmlclue.h"
+#include "htmlclueflow.h"
 #include "htmlobject.h"
 #include "htmlsearch.h"
 #include "htmltextslave.h"
@@ -55,6 +56,53 @@ destroy (HTMLObject *o)
 	HTML_OBJECT_CLASS (parent_class)->destroy (o);
 }
 
+static gint
+get_n_children (HTMLObject *o)
+{
+	HTMLObject *cur = HTML_CLUE (o)->head;
+	gint n_children = 0;
+
+	while (cur) {
+		n_children ++;
+		cur = html_object_next_not_slave (cur);
+	}
+
+	return n_children;
+}
+
+static HTMLObject *
+get_child (HTMLObject *o, gint index)
+{
+	HTMLObject *cur = HTML_CLUE (o)->head;
+
+	g_return_val_if_fail (index >= 0, NULL);
+
+	while (cur) {
+		if (!index)
+			break;
+		index --;
+		cur = html_object_next_not_slave (cur);
+	}
+
+	return cur;
+}
+
+static gint
+get_child_index (HTMLObject *self, HTMLObject *child)
+{
+	HTMLObject *cur = HTML_CLUE (self)->head;
+	gint index = 0;
+
+	while (cur) {
+		if (cur == child)
+			return index;
+		index ++;
+		cur = html_object_next_not_slave (cur);
+	}
+
+	return -1;
+}
+
 static guint
 get_recursive_length (HTMLObject *self)
 {
@@ -234,15 +282,17 @@ set_max_height (HTMLObject *o, HTMLPainter *painter, gint height)
 	HTMLClue *clue = HTML_CLUE (o);
 	HTMLObject *obj;
 
-	for (obj = HTML_CLUE (o)->head; obj != 0; obj = obj->next) {
-		html_object_set_max_height (obj, painter, height);
-		if (clue->valign == HTML_VALIGN_MIDDLE)
-			obj->y = obj->y + ((height - o->ascent) / 2);
-		else if (clue->valign == HTML_VALIGN_BOTTOM)
-			obj->y = obj->y + height - o->ascent;
-	}
+	if (o->ascent < height) {
+		for (obj = HTML_CLUE (o)->head; obj != 0; obj = obj->next) {
+			html_object_set_max_height (obj, painter, height);
+			if (clue->valign == HTML_VALIGN_MIDDLE)
+				obj->y += (height - o->ascent)/2;
+			else if (clue->valign == HTML_VALIGN_BOTTOM)
+				obj->y += height - o->ascent;
+		}
 
-	o->ascent = height;
+		o->ascent = height;
+	}
 }
 
 static void
@@ -259,7 +309,7 @@ reset (HTMLObject *clue)
 }
 
 static gboolean
-calc_size (HTMLObject *o, HTMLPainter *painter, GList **changed_objs)
+html_clue_real_calc_size (HTMLObject *o, HTMLPainter *painter, GList **changed_objs)
 {
 	gboolean changed;
 
@@ -583,7 +633,7 @@ html_clue_class_init (HTMLClueClass *klass,
 	object_class->draw = draw;
 	object_class->set_max_height = set_max_height;
 	object_class->reset = reset;
-	object_class->calc_size = calc_size;
+	object_class->calc_size = html_clue_real_calc_size;
 	object_class->calc_preferred_width = calc_preferred_width;
 	object_class->calc_min_width = calc_min_width;
 	object_class->check_point = check_point;
@@ -598,6 +648,9 @@ html_clue_class_init (HTMLClueClass *klass,
 	object_class->head = head;
 	object_class->tail = tail;
 	object_class->get_recursive_length = get_recursive_length;
+	object_class->get_n_children = get_n_children;
+	object_class->get_child = get_child;
+	object_class->get_child_index = get_child_index;
 
 	/* HTMLClue methods.  */
 	klass->get_left_clear = get_left_clear;
@@ -867,3 +920,15 @@ html_clue_remove_text_slaves (HTMLClue *clue)
 		}
 	}
 }
+
+
+gboolean
+html_clue_is_empty (HTMLClue *clue)
+{
+	if (clue->head == NULL)
+		return TRUE;
+	if (clue->head == clue->tail
+	    && HTML_IS_CLUEFLOW (clue->head) && html_clueflow_is_empty (HTML_CLUEFLOW (clue->head)))
+		return TRUE;
+	return FALSE;
+}
