@@ -67,6 +67,7 @@ struct _HTMLText {
 	guint    text_bytes;
 
 	PangoAttrList    *attr_list;
+	PangoAttrList    *extra_attr_list;
 	GtkHTMLFontStyle  font_style;
 	HTMLFontFace     *face;
 	HTMLColor        *color;
@@ -160,6 +161,7 @@ gint              html_text_text_line_length             (const gchar        *te
 							  gint               *tabs);
 gint              html_text_calc_part_width              (HTMLText           *text,
 							  HTMLPainter        *painter,
+							  char               *start,
 							  gint                offset,
 							  gint                len,
 							  gint               *asc,
@@ -308,6 +310,9 @@ void               html_text_calc_text_size        (HTMLText              *t,
 						    gint                  *width,
 						    gint                  *asc,
 						    gint                  *dsc);
+gboolean           html_text_is_line_break         (PangoItem             *item,
+						    PangoLogAttr          *attrs,
+						    int                    offset);
 
 typedef HTMLObject * (* HTMLTextHelperFunc)       (HTMLText *, gint begin, gint end);
 HTMLObject *html_text_op_copy_helper    (HTMLText           *text,
